@@ -4,8 +4,10 @@ use warnings;
 use Net::RackSpace::CloudServers;
 use Net::RackSpace::CloudServers::Image;
 
-my $user = $ENV{'CLOUDSERVERS_USER'} or die "Need CLOUDSERVERS_USER environment variable set";
-my $key  = $ENV{'CLOUDSERVERS_KEY'}  or die "Need CLOUDSERVERS_KEY environment variable set";
+my $user = $ENV{'CLOUDSERVERS_USER'}
+  or die "Need CLOUDSERVERS_USER environment variable set";
+my $key = $ENV{'CLOUDSERVERS_KEY'}
+  or die "Need CLOUDSERVERS_KEY environment variable set";
 
 my $imgid = shift or die "$0: need ID of image to be deleted\n";
 print "Will delete image ID $imgid\n";
