@@ -4,8 +4,10 @@ use warnings;
 use Net::RackSpace::CloudServers;
 use 5.010_000;
 
-my $user = $ENV{'CLOUDSERVERS_USER'} or die "Need CLOUDSERVERS_USER environment variable set";
-my $key  = $ENV{'CLOUDSERVERS_KEY'}  or die "Need CLOUDSERVERS_KEY environment variable set";
+my $user = $ENV{'CLOUDSERVERS_USER'}
+  or die "Need CLOUDSERVERS_USER environment variable set";
+my $key = $ENV{'CLOUDSERVERS_KEY'}
+  or die "Need CLOUDSERVERS_KEY environment variable set";
 
 $Net::RackSpace::CloudServers::DEBUG = 1;
 warn "** Creating Net::RackSpace::CloudServers object..\n";
